@@ -6,13 +6,13 @@ from pandas_datareader.base import _BaseReader
 
 
 class OECDReader(_BaseReader):
-
     """Get data for the given name from OECD."""
 
     _format = 'json'
 
     @property
     def url(self):
+        """API URL"""
         url = 'http://stats.oecd.org/SDMX-JSON/data'
 
         if not isinstance(self.symbols, compat.string_types):
@@ -26,7 +26,9 @@ class OECDReader(_BaseReader):
         df = read_jsdmx(out)
         try:
             idx_name = df.index.name  # hack for pandas 0.16.2
-            df.index = pd.to_datetime(df.index)
+            df.index = pd.to_datetime(df.index, errors='ignore')
+            for col in df:
+                df[col] = pd.to_numeric(df[col], errors='ignore')
             df = df.sort_index()
             df = df.truncate(self.start, self.end)
             df.index.name = idx_name
