@@ -1,11 +1,9 @@
-import nose
-import pandas.util.testing as tm
 import datetime as dt
 
 import pandas_datareader.tsp as tsp
 
 
-class TestTSPFunds(tm.TestCase):
+class TestTSPFunds(object):
     def test_get_allfunds(self):
         tspdata = tsp.TSPReader(start='2015-11-2', end='2015-11-2').read()
 
@@ -23,8 +21,3 @@ class TestTSPFunds(tm.TestCase):
         r.text = ' a,b '
         ret = tsp.TSPReader._sanitize_response(r)
         assert ret == 'a,b'
-
-
-if __name__ == '__main__':
-    nose.runmodule(argv=[__file__, '-vvs', '-x', '--pdb', '--pdb-failure'],
-                   exit=False)
